==> pacmanlogviewer-1.4.3-1.src.tar.gz: pacmanlogviewer-1.4.3/lang/pacmanlogviewer_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.ui" line="14"/>
        <source>About Pacman Log Viewer</source>
        <translation type="unfinished">Informazioni su Pacman Log Viewer</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="45"/>
        <source>Pacman Log Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="60"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="93"/>
        <source>Inspect pacman log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="100"/>
        <source>Author:</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../aboutdialog.ui" line="112"/>
        <source>Giuseppe Calà</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;a href=&quot;mailto:jiveaxe@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;jiveaxe@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="140"/>
        <source>License:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="150"/>
        <source>GPL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="203"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="14"/>
        <source>Pacman Log Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialog.ui" line="33"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;Pacman Log Viewer&lt;/span&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; Inspect pacman history&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;Pacman Log Viewer&lt;/span&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; Ispeziona il registro di  pacman&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialog.ui" line="81"/>
        <source>package names, comma separated</source>
        <translation>nomi dei pacchetti, separati da una virgola</translation>
    </message>
    <message>
        <location filename="../dialog.ui" line="88"/>
        <source>Exact Match</source>
        <translation>Corrispondenza esatta</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="57"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="58"/>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="59"/>
        <source>Package</source>
        <translation>Pacchetto</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="60"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="70"/>
        <source>&amp;Reload default log</source>
        <translation>&amp;Ricarica registro predefinito</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="71"/>
        <source>&amp;Load custom log</source>
        <translation>&amp;Carica registro personalizzato</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="72"/>
        <source>&amp;About Pacman Log Viewer</source>
        <translation>&amp;Informazioni su Pacman Log Viewer</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="286"/>
        <source>Open Pacman Log File</source>
        <translation>Apri il registro di pacman</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="288"/>
        <source>Logs (*.log)</source>
        <translation>Log (*.log)</translation>
    </message>
</context>
<context>
    <name>FiltersWidget</name>
    <message>
        <location filename="../filterswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="22"/>
        <source>More filters</source>
        <translation type="unfinished">Filtri aggiuntivi</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="83"/>
        <source>Installed</source>
        <translation type="unfinished">Installati</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="98"/>
        <source>Upgraded</source>
        <translation type="unfinished">Aggiornati</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="113"/>
        <source>Removed</source>
        <translation type="unfinished">Rimossi</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="146"/>
        <source>Any time</source>
        <translation type="unfinished">Qualsiasi data</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="151"/>
        <source>Today</source>
        <translation type="unfinished">Oggi</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="156"/>
        <source>Past 2 days</source>
        <translation type="unfinished">Ultimi 2 giorni</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="161"/>
        <source>Past week</source>
        <translation type="unfinished">Ultima settimana</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="166"/>
        <source>Past month</source>
        <translation type="unfinished">Ultimo mese</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="171"/>
        <source>Custom range...</source>
        <translation type="unfinished">Intervallo di date...</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="185"/>
        <source>From:</source>
        <translation type="unfinished">Da:</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="201"/>
        <source>To:</source>
        <translation type="unfinished">A:</translation>
    </message>
</context>
</TS>

==> pacmanlogviewer-1.5.1-3.src.tar.gz: pacmanlogviewer-1.5.1/lang/pacmanlogviewer_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.ui" line="14"/>
        <source>About Pacman Log Viewer</source>
        <translation type="unfinished">Informazioni su Pacman Log Viewer</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="45"/>
        <source>Pacman Log Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="60"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="93"/>
        <source>Inspect pacman log</source>
        <translation type="unfinished">Ispeziona il file di log di pacman</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="100"/>
        <source>Author:</source>
        <translation type="unfinished">Autore:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="112"/>
        <source>Giuseppe Calà</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;a href=&quot;mailto:jiveaxe@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;jiveaxe@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="140"/>
        <source>License:</source>
        <translation type="unfinished">Licenza:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="150"/>
        <source>GPL v3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="203"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="14"/>
        <source>Pacman Log Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialog.ui" line="33"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;Pacman Log Viewer&lt;/span&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; Inspect pacman history&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;Pacman Log Viewer&lt;/span&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; Ispeziona il registro di  pacman&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialog.ui" line="81"/>
        <source>package names, comma separated</source>
        <translation>nomi dei pacchetti, separati da una virgola</translation>
    </message>
    <message>
        <location filename="../dialog.ui" line="88"/>
        <source>Exact Match</source>
        <translation>Corrispondenza esatta</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="64"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="65"/>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="66"/>
        <source>Package</source>
        <translation>Pacchetto</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="67"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="77"/>
        <source>&amp;Reload default log</source>
        <translation>&amp;Ricarica registro predefinito</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="78"/>
        <source>&amp;Load custom log</source>
        <translation>&amp;Carica registro personalizzato</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="79"/>
        <source>&amp;About Pacman Log Viewer</source>
        <translation>&amp;Informazioni su Pacman Log Viewer</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="418"/>
        <source>Open Pacman Log File</source>
        <translation>Apri il registro di pacman</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="420"/>
        <source>Logs (*.log)</source>
        <translation>Log (*.log)</translation>
    </message>
</context>
<context>
    <name>FiltersWidget</name>
    <message>
        <location filename="../filterswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="22"/>
        <source>More filters</source>
        <translation type="unfinished">Filtri aggiuntivi</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="80"/>
        <source>Installed</source>
        <translation type="unfinished">Installati</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="95"/>
        <source>Upgraded</source>
        <translation type="unfinished">Aggiornati</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="110"/>
        <source>Removed</source>
        <translation type="unfinished">Rimossi</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="125"/>
        <source>Downgraded</source>
        <translation type="unfinished">Versione precedente</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="140"/>
        <source>Reinstalled</source>
        <translation type="unfinished">Reinstallati</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="173"/>
        <source>Any time</source>
        <translation type="unfinished">Qualsiasi data</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="178"/>
        <source>Today</source>
        <translation type="unfinished">Oggi</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="183"/>
        <source>Past 2 days</source>
        <translation type="unfinished">Ultimi 2 giorni</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="188"/>
        <source>Past week</source>
        <translation type="unfinished">Ultima settimana</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="193"/>
        <source>Past month</source>
        <translation type="unfinished">Ultimo mese</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="198"/>
        <source>Custom range...</source>
        <translation type="unfinished">Intervallo di date...</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="212"/>
        <source>From:</source>
        <translation type="unfinished">Da:</translation>
    </message>
    <message>
        <location filename="../filterswidget.ui" line="228"/>
        <source>To:</source>
        <translation type="unfinished">A:</translation>
    </message>
</context>
</TS>
